@@ -1,11 +1,10 @@
-
 from openid.extensions.draft import pape5 as pape
 from openid.message import *
 from openid.server import server
 
 import warnings
-warnings.filterwarnings('ignore', module=__name__,
-                        message='"none" used as a policy URI')
+warnings.filterwarnings(
+    'ignore', module=__name__, message='"none" used as a policy URI')
 
 import unittest
 
@@ -21,35 +20,33 @@ class PapeRequestTestCase(unittest.TestCase):
         self.assertFalse(self.req.preferred_auth_level_types)
 
         bogus_levels = ['http://janrain.com/our_levels']
-        req2 = pape.Request(
-            [pape.AUTH_MULTI_FACTOR], 1000, bogus_levels)
+        req2 = pape.Request([pape.AUTH_MULTI_FACTOR], 1000, bogus_levels)
         self.assertEqual([pape.AUTH_MULTI_FACTOR],
-                             req2.preferred_auth_policies)
+                         req2.preferred_auth_policies)
         self.assertEqual(1000, req2.max_auth_age)
         self.assertEqual(bogus_levels, req2.preferred_auth_level_types)
 
     def test_addAuthLevel(self):
         self.req.addAuthLevel('http://example.com/', 'example')
         self.assertEqual(['http://example.com/'],
-                             self.req.preferred_auth_level_types)
+                         self.req.preferred_auth_level_types)
         self.assertEqual('http://example.com/',
-                             self.req.auth_level_aliases['example'])
+                         self.req.auth_level_aliases['example'])
 
         self.req.addAuthLevel('http://example.com/1', 'example1')
         self.assertEqual(['http://example.com/', 'http://example.com/1'],
-                             self.req.preferred_auth_level_types)
+                         self.req.preferred_auth_level_types)
 
         self.req.addAuthLevel('http://example.com/', 'exmpl')
         self.assertEqual(['http://example.com/', 'http://example.com/1'],
-                             self.req.preferred_auth_level_types)
+                         self.req.preferred_auth_level_types)
 
         self.req.addAuthLevel('http://example.com/', 'example')
         self.assertEqual(['http://example.com/', 'http://example.com/1'],
-                             self.req.preferred_auth_level_types)
+                         self.req.preferred_auth_level_types)
 
-        self.assertRaises(KeyError,
-                              self.req.addAuthLevel,
-                              'http://example.com/2', 'example')
+        self.assertRaises(KeyError, self.req.addAuthLevel,
+                          'http://example.com/2', 'example')
 
         # alias is None; we expect a new one to be generated.
         uri = 'http://another.example.com/'
@@ -67,35 +64,36 @@ class PapeRequestTestCase(unittest.TestCase):
         self.assertEqual([], self.req.preferred_auth_policies)
         self.req.addPolicyURI(pape.AUTH_MULTI_FACTOR)
         self.assertEqual([pape.AUTH_MULTI_FACTOR],
-                             self.req.preferred_auth_policies)
+                         self.req.preferred_auth_policies)
         self.req.addPolicyURI(pape.AUTH_MULTI_FACTOR)
         self.assertEqual([pape.AUTH_MULTI_FACTOR],
-                             self.req.preferred_auth_policies)
+                         self.req.preferred_auth_policies)
         self.req.addPolicyURI(pape.AUTH_PHISHING_RESISTANT)
-        self.assertEqual([pape.AUTH_MULTI_FACTOR,
-                              pape.AUTH_PHISHING_RESISTANT],
-                             self.req.preferred_auth_policies)
+        self.assertEqual(
+            [pape.AUTH_MULTI_FACTOR,
+             pape.AUTH_PHISHING_RESISTANT], self.req.preferred_auth_policies)
         self.req.addPolicyURI(pape.AUTH_MULTI_FACTOR)
-        self.assertEqual([pape.AUTH_MULTI_FACTOR,
-                              pape.AUTH_PHISHING_RESISTANT],
-                             self.req.preferred_auth_policies)
+        self.assertEqual(
+            [pape.AUTH_MULTI_FACTOR,
+             pape.AUTH_PHISHING_RESISTANT], self.req.preferred_auth_policies)
 
     def test_getExtensionArgs(self):
-        self.assertEqual({'preferred_auth_policies': ''},
-                             self.req.getExtensionArgs())
+        self.assertEqual({
+            'preferred_auth_policies': ''
+        }, self.req.getExtensionArgs())
         self.req.addPolicyURI('http://uri')
-        self.assertEqual(
-            {'preferred_auth_policies': 'http://uri'},
-            self.req.getExtensionArgs())
+        self.assertEqual({
+            'preferred_auth_policies': 'http://uri'
+        }, self.req.getExtensionArgs())
         self.req.addPolicyURI('http://zig')
-        self.assertEqual(
-            {'preferred_auth_policies': 'http://uri http://zig'},
-            self.req.getExtensionArgs())
+        self.assertEqual({
+            'preferred_auth_policies': 'http://uri http://zig'
+        }, self.req.getExtensionArgs())
         self.req.max_auth_age = 789
-        self.assertEqual(
-            {'preferred_auth_policies': 'http://uri http://zig',
-             'max_auth_age': '789'},
-            self.req.getExtensionArgs())
+        self.assertEqual({
+            'preferred_auth_policies': 'http://uri http://zig',
+            'max_auth_age': '789'
+        }, self.req.getExtensionArgs())
 
     def test_getExtensionArgsWithAuthLevels(self):
         uri = 'http://example.com/auth_level'
@@ -111,7 +109,7 @@ class PapeRequestTestCase(unittest.TestCase):
             ('auth_level.ns.%s' % alias2): uri2,
             'preferred_auth_level_types': ' '.join([alias, alias2]),
             'preferred_auth_policies': '',
-            }
+        }
 
         self.assertEqual(expected_args, self.req.getExtensionArgs())
 
@@ -127,10 +125,11 @@ class PapeRequestTestCase(unittest.TestCase):
             ('auth_level.ns.%s' % alias2): uri2,
             'preferred_auth_level_types': ' '.join([alias, alias2]),
             'preferred_auth_policies': '',
-            }
+        }
 
         # Check request object state
-        self.req.parseExtensionArgs(request_args, is_openid1=False, strict=False)
+        self.req.parseExtensionArgs(
+            request_args, is_openid1=False, strict=False)
 
         expected_auth_levels = [uri, uri2]
 
@@ -141,8 +140,8 @@ class PapeRequestTestCase(unittest.TestCase):
 
     def test_parseExtensionArgsWithAuthLevels_openID1(self):
         request_args = {
-            'preferred_auth_level_types':'nist jisa',
-            }
+            'preferred_auth_level_types': 'nist jisa',
+        }
         expected_auth_levels = [pape.LEVELS_NIST, pape.LEVELS_JISA]
         self.req.parseExtensionArgs(request_args, is_openid1=True)
         self.assertEqual(expected_auth_levels,
@@ -150,37 +149,49 @@ class PapeRequestTestCase(unittest.TestCase):
 
         self.req = pape.Request()
         self.req.parseExtensionArgs(request_args, is_openid1=False)
-        self.assertEqual([],
-                         self.req.preferred_auth_level_types)
+        self.assertEqual([], self.req.preferred_auth_level_types)
 
         self.req = pape.Request()
-        self.assertRaises(ValueError,
-                              self.req.parseExtensionArgs,
-                              request_args, is_openid1=False, strict=True)
+        self.assertRaises(
+            ValueError,
+            self.req.parseExtensionArgs,
+            request_args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_ignoreBadAuthLevels(self):
-        request_args = {'preferred_auth_level_types':'monkeys'}
+        request_args = {'preferred_auth_level_types': 'monkeys'}
         self.req.parseExtensionArgs(request_args, False)
         self.assertEqual([], self.req.preferred_auth_level_types)
 
     def test_parseExtensionArgs_strictBadAuthLevels(self):
-        request_args = {'preferred_auth_level_types':'monkeys'}
-        self.assertRaises(ValueError, self.req.parseExtensionArgs,
-                              request_args, is_openid1=False, strict=True)
+        request_args = {'preferred_auth_level_types': 'monkeys'}
+        self.assertRaises(
+            ValueError,
+            self.req.parseExtensionArgs,
+            request_args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs(self):
-        args = {'preferred_auth_policies': 'http://foo http://bar',
-                'max_auth_age': '9'}
+        args = {
+            'preferred_auth_policies': 'http://foo http://bar',
+            'max_auth_age': '9'
+        }
         self.req.parseExtensionArgs(args, False)
         self.assertEqual(9, self.req.max_auth_age)
-        self.assertEqual(['http://foo','http://bar'],
-                             self.req.preferred_auth_policies)
+        self.assertEqual(['http://foo', 'http://bar'],
+                         self.req.preferred_auth_policies)
         self.assertEqual([], self.req.preferred_auth_level_types)
 
     def test_parseExtensionArgs_strict_bad_auth_age(self):
         args = {'max_auth_age': 'not an int'}
-        self.assertRaises(ValueError, self.req.parseExtensionArgs, args,
-                          is_openid1=False, strict=True)
+        self.assertRaises(
+            ValueError,
+            self.req.parseExtensionArgs,
+            args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_empty(self):
         self.req.parseExtensionArgs({}, False)
@@ -191,12 +202,17 @@ class PapeRequestTestCase(unittest.TestCase):
     def test_fromOpenIDRequest(self):
         policy_uris = [pape.AUTH_MULTI_FACTOR, pape.AUTH_PHISHING_RESISTANT]
         openid_req_msg = Message.fromOpenIDArgs({
-          'mode': 'checkid_setup',
-          'ns': OPENID2_NS,
-          'ns.pape': pape.ns_uri,
-          'pape.preferred_auth_policies': ' '.join(policy_uris),
-          'pape.max_auth_age': '5476'
-          })
+            'mode':
+            'checkid_setup',
+            'ns':
+            OPENID2_NS,
+            'ns.pape':
+            pape.ns_uri,
+            'pape.preferred_auth_policies':
+            ' '.join(policy_uris),
+            'pape.max_auth_age':
+            '5476'
+        })
         oid_req = server.OpenIDRequest()
         oid_req.message = openid_req_msg
         req = pape.Request.fromOpenIDRequest(oid_req)
@@ -208,15 +224,16 @@ class PapeRequestTestCase(unittest.TestCase):
         openid_req = server.OpenIDRequest()
         openid_req.message = message
         pape_req = pape.Request.fromOpenIDRequest(openid_req)
-        assert(pape_req is None)
+        assert (pape_req is None)
 
     def test_preferred_types(self):
         self.req.addPolicyURI(pape.AUTH_PHISHING_RESISTANT)
         self.req.addPolicyURI(pape.AUTH_MULTI_FACTOR)
-        pt = self.req.preferredTypes([pape.AUTH_MULTI_FACTOR,
-                                      pape.AUTH_MULTI_FACTOR_PHYSICAL])
+        pt = self.req.preferredTypes(
+            [pape.AUTH_MULTI_FACTOR, pape.AUTH_MULTI_FACTOR_PHYSICAL])
         self.assertEqual([pape.AUTH_MULTI_FACTOR], pt)
 
+
 class DummySuccessResponse:
     def __init__(self, message, signed_stuff):
         self.message = message
@@ -228,6 +245,7 @@ class DummySuccessResponse:
     def getSignedNS(self, ns_uri):
         return self.signed_stuff
 
+
 class PapeResponseTestCase(unittest.TestCase):
     def setUp(self):
         self.resp = pape.Response()
@@ -238,8 +256,8 @@ class PapeResponseTestCase(unittest.TestCase):
         self.assertEqual('pape', self.resp.ns_alias)
         self.assertEqual(None, self.resp.nist_auth_level)
 
-        req2 = pape.Response([pape.AUTH_MULTI_FACTOR],
-                             "2004-12-11T10:30:44Z", {pape.LEVELS_NIST: 3})
+        req2 = pape.Response([pape.AUTH_MULTI_FACTOR], "2004-12-11T10:30:44Z",
+                             {pape.LEVELS_NIST: 3})
         self.assertEqual([pape.AUTH_MULTI_FACTOR], req2.auth_policies)
         self.assertEqual("2004-12-11T10:30:44Z", req2.auth_time)
         self.assertEqual(3, req2.nist_auth_level)
@@ -251,50 +269,53 @@ class PapeResponseTestCase(unittest.TestCase):
         self.resp.addPolicyURI(pape.AUTH_MULTI_FACTOR)
         self.assertEqual([pape.AUTH_MULTI_FACTOR], self.resp.auth_policies)
         self.resp.addPolicyURI(pape.AUTH_PHISHING_RESISTANT)
-        self.assertEqual([pape.AUTH_MULTI_FACTOR,
-                              pape.AUTH_PHISHING_RESISTANT],
-                             self.resp.auth_policies)
+        self.assertEqual(
+            [pape.AUTH_MULTI_FACTOR,
+             pape.AUTH_PHISHING_RESISTANT], self.resp.auth_policies)
         self.resp.addPolicyURI(pape.AUTH_MULTI_FACTOR)
-        self.assertEqual([pape.AUTH_MULTI_FACTOR,
-                              pape.AUTH_PHISHING_RESISTANT],
-                             self.resp.auth_policies)
+        self.assertEqual(
+            [pape.AUTH_MULTI_FACTOR,
+             pape.AUTH_PHISHING_RESISTANT], self.resp.auth_policies)
 
-        self.assertRaises(RuntimeError, self.resp.addPolicyURI,
-                              pape.AUTH_NONE)
+        self.assertRaises(RuntimeError, self.resp.addPolicyURI, pape.AUTH_NONE)
 
     def test_getExtensionArgs(self):
-        self.assertEqual({'auth_policies': pape.AUTH_NONE},
-                             self.resp.getExtensionArgs())
+        self.assertEqual({
+            'auth_policies': pape.AUTH_NONE
+        }, self.resp.getExtensionArgs())
         self.resp.addPolicyURI('http://uri')
-        self.assertEqual({'auth_policies': 'http://uri'},
-                             self.resp.getExtensionArgs())
+        self.assertEqual({
+            'auth_policies': 'http://uri'
+        }, self.resp.getExtensionArgs())
         self.resp.addPolicyURI('http://zig')
-        self.assertEqual({'auth_policies': 'http://uri http://zig'},
-                             self.resp.getExtensionArgs())
+        self.assertEqual({
+            'auth_policies': 'http://uri http://zig'
+        }, self.resp.getExtensionArgs())
         self.resp.auth_time = "1776-07-04T14:43:12Z"
-        self.assertEqual(
-            {'auth_policies': 'http://uri http://zig',
-             'auth_time': "1776-07-04T14:43:12Z"},
-            self.resp.getExtensionArgs())
+        self.assertEqual({
+            'auth_policies': 'http://uri http://zig',
+            'auth_time': "1776-07-04T14:43:12Z"
+        }, self.resp.getExtensionArgs())
         self.resp.setAuthLevel(pape.LEVELS_NIST, '3')
-        self.assertEqual(
-            {'auth_policies': 'http://uri http://zig',
-             'auth_time': "1776-07-04T14:43:12Z",
-             'auth_level.nist': '3',
-             'auth_level.ns.nist': pape.LEVELS_NIST},
-            self.resp.getExtensionArgs())
+        self.assertEqual({
+            'auth_policies': 'http://uri http://zig',
+            'auth_time': "1776-07-04T14:43:12Z",
+            'auth_level.nist': '3',
+            'auth_level.ns.nist': pape.LEVELS_NIST
+        }, self.resp.getExtensionArgs())
 
     def test_getExtensionArgs_error_auth_age(self):
         self.resp.auth_time = "long ago"
         self.assertRaises(ValueError, self.resp.getExtensionArgs)
 
     def test_parseExtensionArgs(self):
-        args = {'auth_policies': 'http://foo http://bar',
-                'auth_time': '1970-01-01T00:00:00Z'}
+        args = {
+            'auth_policies': 'http://foo http://bar',
+            'auth_time': '1970-01-01T00:00:00Z'
+        }
         self.resp.parseExtensionArgs(args, is_openid1=False)
         self.assertEqual('1970-01-01T00:00:00Z', self.resp.auth_time)
-        self.assertEqual(['http://foo','http://bar'],
-                             self.resp.auth_policies)
+        self.assertEqual(['http://foo', 'http://bar'], self.resp.auth_policies)
 
     def test_parseExtensionArgs_valid_none(self):
         args = {'auth_policies': pape.AUTH_NONE}
@@ -310,7 +331,10 @@ class PapeResponseTestCase(unittest.TestCase):
         args = {'auth_policies': 'none'}
         self.assertRaises(
             ValueError,
-            self.resp.parseExtensionArgs, args, is_openid1=False, strict=True)
+            self.resp.parseExtensionArgs,
+            args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_empty(self):
         self.resp.parseExtensionArgs({}, is_openid1=False)
@@ -320,14 +344,16 @@ class PapeResponseTestCase(unittest.TestCase):
     def test_parseExtensionArgs_empty_strict(self):
         self.assertRaises(
             ValueError,
-            self.resp.parseExtensionArgs, {}, is_openid1=False, strict=True)
+            self.resp.parseExtensionArgs, {},
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_ignore_superfluous_none(self):
         policies = [pape.AUTH_NONE, pape.AUTH_MULTI_FACTOR_PHYSICAL]
 
         args = {
             'auth_policies': ' '.join(policies),
-            }
+        }
 
         self.resp.parseExtensionArgs(args, is_openid1=False, strict=False)
 
@@ -339,21 +365,32 @@ class PapeResponseTestCase(unittest.TestCase):
 
         args = {
             'auth_policies': ' '.join(policies),
-            }
+        }
 
-        self.assertRaises(ValueError, self.resp.parseExtensionArgs,
-                              args, is_openid1=False, strict=True)
+        self.assertRaises(
+            ValueError,
+            self.resp.parseExtensionArgs,
+            args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_strict_bogus1(self):
-        args = {'auth_policies': 'http://foo http://bar',
-                'auth_time': 'yesterday'}
-        self.assertRaises(ValueError, self.resp.parseExtensionArgs,
-                              args, is_openid1=False, strict=True)
+        args = {
+            'auth_policies': 'http://foo http://bar',
+            'auth_time': 'yesterday'
+        }
+        self.assertRaises(
+            ValueError,
+            self.resp.parseExtensionArgs,
+            args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_openid1_strict(self):
-        args = {'auth_level.nist': '0',
-                'auth_policies': pape.AUTH_NONE,
-                }
+        args = {
+            'auth_level.nist': '0',
+            'auth_policies': pape.AUTH_NONE,
+        }
         self.resp.parseExtensionArgs(args, strict=True, is_openid1=True)
         self.assertEqual('0', self.resp.getAuthLevel(pape.LEVELS_NIST))
         self.assertEqual([], self.resp.auth_policies)
@@ -361,57 +398,69 @@ class PapeResponseTestCase(unittest.TestCase):
     def test_parseExtensionArgs_strict_no_namespace_decl_openid2(self):
         # Test the case where the namespace is not declared for an
         # auth level.
-        args = {'auth_policies': pape.AUTH_NONE,
-                'auth_level.nist': '0',
-                }
-        self.assertRaises(ValueError, self.resp.parseExtensionArgs,
-                              args, is_openid1=False, strict=True)
+        args = {
+            'auth_policies': pape.AUTH_NONE,
+            'auth_level.nist': '0',
+        }
+        self.assertRaises(
+            ValueError,
+            self.resp.parseExtensionArgs,
+            args,
+            is_openid1=False,
+            strict=True)
 
     def test_parseExtensionArgs_nostrict_no_namespace_decl_openid2(self):
         # Test the case where the namespace is not declared for an
         # auth level.
-        args = {'auth_policies': pape.AUTH_NONE,
-                'auth_level.nist': '0',
-                }
+        args = {
+            'auth_policies': pape.AUTH_NONE,
+            'auth_level.nist': '0',
+        }
         self.resp.parseExtensionArgs(args, is_openid1=False, strict=False)
 
         # There is no namespace declaration for this auth level.
-        self.assertRaises(KeyError, self.resp.getAuthLevel,
-                              pape.LEVELS_NIST)
+        self.assertRaises(KeyError, self.resp.getAuthLevel, pape.LEVELS_NIST)
 
     def test_parseExtensionArgs_strict_good(self):
-        args = {'auth_policies': 'http://foo http://bar',
-                'auth_time': '1970-01-01T00:00:00Z',
-                'auth_level.nist': '0',
-                'auth_level.ns.nist': pape.LEVELS_NIST}
+        args = {
+            'auth_policies': 'http://foo http://bar',
+            'auth_time': '1970-01-01T00:00:00Z',
+            'auth_level.nist': '0',
+            'auth_level.ns.nist': pape.LEVELS_NIST
+        }
         self.resp.parseExtensionArgs(args, is_openid1=False, strict=True)
-        self.assertEqual(['http://foo','http://bar'],
-                             self.resp.auth_policies)
+        self.assertEqual(['http://foo', 'http://bar'], self.resp.auth_policies)
         self.assertEqual('1970-01-01T00:00:00Z', self.resp.auth_time)
         self.assertEqual(0, self.resp.nist_auth_level)
 
     def test_parseExtensionArgs_nostrict_bogus(self):
-        args = {'auth_policies': 'http://foo http://bar',
-                'auth_time': 'when the cows come home',
-                'nist_auth_level': 'some'}
+        args = {
+            'auth_policies': 'http://foo http://bar',
+            'auth_time': 'when the cows come home',
+            'nist_auth_level': 'some'
+        }
         self.resp.parseExtensionArgs(args, is_openid1=False)
-        self.assertEqual(['http://foo','http://bar'],
-                             self.resp.auth_policies)
+        self.assertEqual(['http://foo', 'http://bar'], self.resp.auth_policies)
         self.assertEqual(None, self.resp.auth_time)
         self.assertEqual(None, self.resp.nist_auth_level)
 
     def test_fromSuccessResponse(self):
         policy_uris = [pape.AUTH_MULTI_FACTOR, pape.AUTH_PHISHING_RESISTANT]
         openid_req_msg = Message.fromOpenIDArgs({
-          'mode': 'id_res',
-          'ns': OPENID2_NS,
-          'ns.pape': pape.ns_uri,
-          'pape.auth_policies': ' '.join(policy_uris),
-          'pape.auth_time': '1970-01-01T00:00:00Z'
-          })
+            'mode':
+            'id_res',
+            'ns':
+            OPENID2_NS,
+            'ns.pape':
+            pape.ns_uri,
+            'pape.auth_policies':
+            ' '.join(policy_uris),
+            'pape.auth_time':
+            '1970-01-01T00:00:00Z'
+        })
         signed_stuff = {
-          'auth_policies': ' '.join(policy_uris),
-          'auth_time': '1970-01-01T00:00:00Z'
+            'auth_policies': ' '.join(policy_uris),
+            'auth_time': '1970-01-01T00:00:00Z'
         }
         oid_req = DummySuccessResponse(openid_req_msg, signed_stuff)
         req = pape.Response.fromSuccessResponse(oid_req)
@@ -421,12 +470,17 @@ class PapeResponseTestCase(unittest.TestCase):
     def test_fromSuccessResponseNoSignedArgs(self):
         policy_uris = [pape.AUTH_MULTI_FACTOR, pape.AUTH_PHISHING_RESISTANT]
         openid_req_msg = Message.fromOpenIDArgs({
-          'mode': 'id_res',
-          'ns': OPENID2_NS,
-          'ns.pape': pape.ns_uri,
-          'pape.auth_policies': ' '.join(policy_uris),
-          'pape.auth_time': '1970-01-01T00:00:00Z'
-          })
+            'mode':
+            'id_res',
+            'ns':
+            OPENID2_NS,
+            'ns.pape':
+            pape.ns_uri,
+            'pape.auth_policies':
+            ' '.join(policy_uris),
+            'pape.auth_time':
+            '1970-01-01T00:00:00Z'
+        })
 
         signed_stuff = {}
 
@@ -438,5 +492,6 @@ class PapeResponseTestCase(unittest.TestCase):
         resp = pape.Response.fromSuccessResponse(oid_req)
         self.assertTrue(resp is None)
 
+
 if __name__ == '__main__':
     unittest.main()
