@@ -9,5 +9,4 @@ YADIS_CONTENT_TYPE = 'application/xrds+xml'
 YADIS_ACCEPT_HEADER = generateAcceptHeader(
     ('text/html', 0.3),
     ('application/xhtml+xml', 0.5),
-    (YADIS_CONTENT_TYPE, 1.0),
-    )
+    (YADIS_CONTENT_TYPE, 1.0), )
